@@ -62,18 +62,31 @@ def preprocessing_training_common(df, config, model_type, mapping_dicts=None, im
     if mapping_dicts is None:
         logger.info("No mapping dicts present, creating them")
         mapping_dicts = {}
-        mx_prob_dictionary, mx_bv_dictionary = DEutils.create_class_dictionaries(df, "MXType")
-        df = DEutils.map_conv_prob_using_dictionary(df, mx_prob_dictionary, mx_bv_dictionary, 'MXType')
-        mapping_dicts['mx_prob'] = mx_prob_dictionary
-        mapping_dicts['mx_bv'] = mx_bv_dictionary
-        state_prob_dictionary, state_bv_dictionary = DEutils.create_class_dictionaries(df, "State")
-        df = DEutils.map_conv_prob_using_dictionary(df, state_prob_dictionary, state_bv_dictionary, 'State')
-        mapping_dicts['state_prob'] = state_prob_dictionary
-        mapping_dicts['state_bv'] = state_bv_dictionary
-        industry_prob_dictionary, industry_bv_dictionary = DEutils.create_class_dictionaries(df, "Industry")
-        df = DEutils.map_conv_prob_using_dictionary(df, industry_prob_dictionary, industry_bv_dictionary, 'Industry')
-        mapping_dicts['industry_prob'] = industry_prob_dictionary
-        mapping_dicts['industry_bv'] = industry_bv_dictionary
+
+        mapping_dicts = DEutils.create_class_dictionaries(df,
+                                                          "MXType")
+        df = DEutils.map_conv_prob_using_dictionary(df,
+                                                    mapping_dicts,
+                                                    'MXType')
+        mapping_dicts = DEutils.create_class_dictionaries(df,
+                                                          mapping_dicts,
+                                                          "State")
+        df = DEutils.map_conv_prob_using_dictionary(df,
+                                                    mapping_dicts,
+                                                    'State')
+        mapping_dicts = DEutils.create_class_dictionaries(df,
+                                                          mapping_dicts,
+                                                          "Industry")
+        df = DEutils.map_conv_prob_using_dictionary(df,
+                                                    mapping_dicts,
+                                                    'Industry')
+        mapping_dicts = DEutils.create_class_dictionaries(df,
+                                                          mapping_dicts,
+                                                          "PreviousContacts")
+        df = DEutils.map_conv_prob_using_dictionary(df,
+                                                    mapping_dicts,
+                                                    'PreviousContacts',
+                                                    drop=False)
 
         mapping_dicts_name = 'mapping_dicts' + config['campaign'] + '.pkl'
         mapping_dicts_output_path = os.path.join('/opt/ml/processing/mapping_dicts', mapping_dicts_name)
@@ -82,14 +95,20 @@ def preprocessing_training_common(df, config, model_type, mapping_dicts=None, im
     else:
         logging.info("Mapping dicts found! Using them")
         df = DEutils.map_conv_prob_using_dictionary(df,
-                                                    mapping_dicts['mx_prob'], mapping_dicts['mx_bv'], 'MXType')
+                                                    mapping_dicts,
+                                                    'MXType')
 
         df = DEutils.map_conv_prob_using_dictionary(df,
-                                                    mapping_dicts['state_prob'], mapping_dicts['state_bv'], 'State')
+                                                    mapping_dicts,
+                                                    'State')
 
         df = DEutils.map_conv_prob_using_dictionary(df,
-                                                    mapping_dicts['industry_prob'], mapping_dicts['industry_bv'],
+                                                    mapping_dicts,
                                                     'Industry')
+        df = DEutils.map_conv_prob_using_dictionary(df,
+                                                    mapping_dicts,
+                                                    'PreviousContacts',
+                                                    drop=False)
 
     return df, imp, mapping_dicts
 
@@ -124,10 +143,10 @@ s
 
     # Convert to categories and 
     df_leads_clean, imp, mapping_dicts = preprocessing_training_common(df=df_leads_clean,
-                                                        config=config,
-                                                        mapping_dicts=mapping_dicts,
-                                                        model_type=model_type,
-                                                        imp=imp)
+                                                                       config=config,
+                                                                       mapping_dicts=mapping_dicts,
+                                                                       model_type=model_type,
+                                                                       imp=imp)
 
     df_leads_clean = utils.reduce_mem_usage_category(df=df_leads_clean)
 
@@ -141,43 +160,4 @@ s
     logging.info("NA in final dataframe:")
     logging.info(f"{nna}")
 
-    return df_leads_clean, imp , mapping_dicts
-
-
-def preprocessing_predictions(df, imputer, mapping_dicts: dict, config: dict, training_sample,fill_value=0):
-    df = (df.pipe(utils.reduce_mem_usage).
-          pipe(DEutils.set_dataframe_columntypes)
-          .pipe(DEutils.clean_companytype)
-          .pipe(DEutils.fill_na_with_unknown,
-                columns=config['fill_unknown'])
-          .pipe(DEutils.create_company_years_column)
-          .pipe(DEutils.fill_seniority_column)
-          .pipe(DEutils.clean_companyfollowers_text)
-          .pipe(DEutils.filter_countries)
-          .pipe(DEutils.convert_kwkey_specialties_and_technologies_to_int)
-          .pipe(DEutils.fill_variables)
-          .pipe(DEutils.impute_growth)
-          .pipe(DEutils.impute_nas,
-                columns_to_impute=config['impute_columns'],
-                imp=imputer)
-          .pipe(DEutils.log_transformation, columns=config['cols_to_transform'])
-          .pipe(DEutils.map_conv_prob_using_dictionary,
-                mapping_dicts['mx_prob'],
-                mapping_dicts['mx_bv'],
-                'MXType')
-          .pipe(DEutils.map_conv_prob_using_dictionary,
-                mapping_dicts['state_prob'],
-                mapping_dicts['state_bv'],
-                'State')
-          .pipe(DEutils.map_conv_prob_using_dictionary,
-                mapping_dicts['industry_prob'],
-                mapping_dicts['industry_bv'],
-                'Industry')
-          .pipe(DEutils.drop_columns, columns=config['cols_to_drop'])
-          .pipe(utils.reduce_mem_usage_category)
-          .pipe(DEutils.one_hot_encoding)
-          .pipe(DEutils.align_dataframe_with_sample,
-                training_sample,
-                fill_value)
-          )
-    return df
+    return df_leads_clean, imp, mapping_dicts
