@@ -101,13 +101,12 @@ def set_dataframe_columntypes(df):
     if 'DaysSincePositionStart' in df:
         df['DaysSincePositionStart'] = df['DaysSincePositionStart'].astype('float16')
 
-
     logger.info("Datatypes after modification")
     logger.info(f'{df.dtypes}')
 
-
     return df
 
+
 def one_hot_encoding(df):
     """Generate one hot encoded dataset
     WARNING:
@@ -132,9 +131,10 @@ def one_hot_encoding(df):
     logging.info(f"{df.dtypes}")
     return df
 
-def align_dataframe_with_sample(df,sample, fillvalue=0):
+
+def align_dataframe_with_sample(df, sample, fillvalue=0):
     logger.info('aligning dataframe with sample')
-    _,df = sample.align(
+    _, df = sample.align(
         df,
         join='left',
         axis=1,
@@ -142,6 +142,7 @@ def align_dataframe_with_sample(df,sample, fillvalue=0):
     )
     return df
 
+
 def convert_date(df):
     # Convert date
     if 'campaign_bulk_date' in df.columns:
@@ -152,6 +153,7 @@ def convert_date(df):
         raise Exception('campaign_bulk_date not present! unable to perform dataset split')
     return df
 
+
 def drop_columns(df, columns):
     """Drops the selected columns
 
@@ -243,6 +245,7 @@ def correct_C80_success_code(df):
 
     return df
 
+
 def set_idemailstatus_target_column(df):
     if ('IDEmailStatus' in df.columns):
         logger.info('Setting E-Mail status target ')
@@ -410,9 +413,9 @@ def process_bulkstatus(df):
 
 def impute_growth(df):
     logger.info("Applying growth imputation")
-    df['Growth12M'] = df['Growth12M'].fillna(df['Growth6M']*2)
-    df['Growth6M'] = df['Growth6M'].fillna(df['Growth3M']*2)
-    df['Growth3M'] = df['Growth3M'].fillna(df['Growth6M']/2)
+    df['Growth12M'] = df['Growth12M'].fillna(df['Growth6M'] * 2)
+    df['Growth6M'] = df['Growth6M'].fillna(df['Growth3M'] * 2)
+    df['Growth3M'] = df['Growth3M'].fillna(df['Growth6M'] / 2)
 
     return df
 
@@ -582,28 +585,34 @@ def clean_mxtype(df, mxtypes):
     return df
 
 
-def create_class_dictionaries(df_original,class_to_use:str):
-    logger.info(f'Creating dictionaries for {class_to_use}')
-    df=df_original[[class_to_use, 'BV', 'IDEmailStatus']].copy()
-    df['BV']=df['BV'].fillna(0)
+def create_class_dictionaries(df_original, mapping_dicts, column: str):
+    logger.info(f'Creating dictionaries for {column}')
+    df = df_original[[column, 'BV', 'IDEmailStatus']].copy()
+    df['BV'] = df['BV'].fillna(0)
     df.loc[(df['IDEmailStatus'] != 14) &
-             (df['IDEmailStatus'] != 31), 'IDEmailStatus'] = 0
+           (df['IDEmailStatus'] != 31), 'IDEmailStatus'] = 0
     df.loc[df['IDEmailStatus'] == 14, 'IDEmailStatus'] = 1
     df.loc[df['IDEmailStatus'] == 31, 'IDEmailStatus'] = 1
-    groupby = df.groupby(class_to_use,dropna=False).agg(BV=('BV', 'mean'),
-                                           Conversions=('IDEmailStatus', 'mean')
-                                           )
+    groupby = df.groupby(column, dropna=False).agg(BV=('BV', 'mean'),
+                                                         Conversions=('IDEmailStatus', 'mean')
+                                                         )
     groupby = groupby.reset_index()
     logger.info(f"{groupby.head()}")
     list_dict = groupby.to_dict(orient='records')
     conversion_dict = {}
     bv_dict = {}
     for element in list_dict:
-        conversion_dict[f'{element[class_to_use]}'] = element['Conversions']
-        bv_dict[f'{element[class_to_use]}'] = element['BV']
-    return conversion_dict,bv_dict
+        conversion_dict[f'{element[column]}'] = element['Conversions']
+        bv_dict[f'{element[column]}'] = element['BV']
 
-def clean_mxtype_using_dictionary(df,mx_bv_dict,mx_prob_dict):
+    bv_col = column + "_bv"
+    mapping_dicts[bv_col]=bv_dict
+    prob_col=column+"_prob"
+    mapping_dicts[prob_col]=conversion_dict
+    return mapping_dicts
+
+
+def clean_mxtype_using_dictionary(df, mx_bv_dict, mx_prob_dict):
     """
 
     :param df: Input Dataset
@@ -613,18 +622,18 @@ def clean_mxtype_using_dictionary(df,mx_bv_dict,mx_prob_dict):
     """
 
     if 'MXType' not in df.columns:
-        raise Exception ("MXType column not preset ( Check Caps)")
+        raise Exception("MXType column not preset ( Check Caps)")
     logger.info('Defining MXTypes')
     df['mx_bv'] = df['MXType']
     df = df.replace({'mx_bv': mx_bv_dict})
     logger.info(f'{df.mx_bv.value_counts()}')
     df['mx_prob'] = df['MXType']
-    df = df.replace( {'mx_prob': mx_prob_dict} )
+    df = df.replace({'mx_prob': mx_prob_dict})
     logger.info(f'{df.mx_prob.value_counts()}')
     return df
 
 
-def map_conv_prob_using_dictionary(df, prob_dict, bv_dict, column:str):
+def map_conv_prob_using_dictionary(df, mapping_dicts, column: str, drop: bool = True):
     """
 
     :param df: Input Dataset
@@ -636,11 +645,13 @@ def map_conv_prob_using_dictionary(df, prob_dict, bv_dict, column:str):
     if column not in df.columns:
         raise Exception("MXType column not preset ( Check Caps)")
     logger.info(f'mapping bv and prob dicts for {column}')
-    bv_col = column+"_bv"
-    df[bv_col] = df[column].map(bv_dict)
-    prob_col = column+"_prob"
-    df[prob_col] = df[column].map(prob_dict)
-    df.drop(column,axis=1,inplace=True)
+    bv_col = column + "_bv"
+    df[bv_col] = df[column].map(mapping_dicts[bv_col])
+    prob_col = column + "_prob"
+    df[prob_col] = df[column].map(mapping_dicts[prob_col])
+    if drop:
+        logger.info("Dropping Column")
+        df.drop(column, axis=1, inplace=True)
     return df
 
 
